@@ -5,4 +5,4 @@ from .models import *
 from importlib_metadata import version
 print(version('inspr'))
 
-from .controller.controller_client import *
\ No newline at end of file
+from .controller.controller_client import ControllerClient
\ No newline at end of file
